/// 将获取到的数据进行解析，每个回放视频对应了一个ReplayVideoData对象
/// 由于回放视频的属性比较多且大多数可能会用不到，故只解析了部分重要常用的
/// 属性，如果需要其他未解析的字段，请参考官方response的数据结构自行解析
/// https://cloud.tencent.com/document/api/266/31773#MediaInfo
///
/// 类中的各个字段是私有的 可以通过对应的get方法来获取
///
/// 类中除了一个构造函数外，还有一个时间转换函数，可以将视频时长从秒
/// 转换成 xx时：xx分：xx秒 的格式，方便UI展示
class ReplayVideoData {
  /********************点播文件的部分基础信息(MediaBasicInfo)************************/

  /// 媒体文件名称 ，媒体文件描述
  String _name;
  String _description;
  /// 媒体文件的创建，更新，过期时间
  String _createTime;
  String _upDate;
  String _expireTime;
  /// 媒体文件的分类名称
  String _className;
  /// 媒体文件封面图片的url地址
  String _coverUrl;
  /// 媒体文件的封装格式 如：mp4，flv等
  String _type;
  /// 文件类型 如Video 视频文件，Audio 音频文件， Image 图片文件
  String _category;
  /// 原始媒体文件的URL地址，用于播放媒体文件
  String _mediaUrl;
  /// 直播录制文件的唯一标识
  String _vId;
  /// String _status;  用于标识媒体文件的状态：Normal 正常，Forbidden： 封禁，但腾讯云
  /// 表示但不支持此字段
  /// 媒体文件的分类ID
  int _classId;

  /********************点播文件的部分元信息(MediaMetaData)************************/

  /// 上传的媒体文件的文件大小，单位是字节
  int _size;
  /// duration与videoDuration均为视频时长，audioDuration为音频时长，三者单位均为秒，且
  /// 返回的原始应答数据为float类型
  double _duration;
  double _videoDuration;
  double _audioDuration;
  /// 视频流的宽度和高度的最大值，单位为：px
  int _width;
  int _height;

  String get description => _description;
  String get name => _name;
  String get createTime => _createTime;
  String get upDate => _upDate;
  String get expireTime => _expireTime;
  String get className => _className;
  String get coverUrl => _coverUrl;
  String get type => _type;
  String get category => _category;
  String get mediaUrl => _mediaUrl;
  String get vId => _vId;
  /// String get status => _status;
  int get classId => _classId;
  int get size => _size;
  double get duration => _duration;
  double get videoDuration => _videoDuration;
  double get audioDuration => _audioDuration;
  int get width => _width;
  int get height => _height;

  /// 构造函数，部分重要信息为必需参数
  ReplayVideoData(
      this._name,
      this._createTime,
      this._className,
      this._coverUrl,
      this._type,
      this._mediaUrl,
      this._vId,
      this._classId,
      this._size,
      this._duration,{
        description = "null",
        upDate = 'null',
        expireTime = '9999-12-31T23:59:59Z',
        category = 'Video',
        videoDuration = 0.0,
        audioDuration = 0.0,
        width = 640,
        height = 368,
      })  : _description = description,
        _upDate = upDate,
        _expireTime = expireTime,
        _category = category,
        _videoDuration = videoDuration,
        _audioDuration = audioDuration,
        _width = width,
        _height = height;

  /// 得到的应答数据中的视频时长单位为秒，且为float类型，为了方便展示，将秒转化为
  /// xx时：xx分：xx秒 的字符串格式
  String convertDuration(double duration){
    if(duration < 60 ){
      return duration.toString()+"秒";
    }
    String timeDuration = '';
    /// 计算小时
    if((duration ~/ 3600) != 0){
      if((duration ~/ 3600) < 10){
        timeDuration += '0';
      }
      timeDuration += (duration ~/ 3600).toString() + '时:';
    }
    /// 计算分钟
    if ((duration % 3600 ~/ 60) < 10) {
      timeDuration += '0';
    }
    timeDuration += (duration % 3600 ~/ 60).toString() + '分:';
    /// 计算秒,并取整
    if ((duration % 60 ~/ 1) < 10) {
      timeDuration += '0';
    }
    timeDuration += (duration % 60 ~/ 1).toString() + '秒';
    return timeDuration;
  }
}
